Dialog API Schema
=================

[![Build Status](https://img.shields.io/circleci/project/github/dialogs/api-schema/master.svg)](https://circleci.com/gh/dialogs/api-schema)

[![npm](https://img.shields.io/npm/v/@dlghq/dialog-api)](https://www.npmjs.com/package/@dlghq/dialog-api)
[![Maven](https://img.shields.io/bintray/v/dialog/maven/java-api-schema?label=Maven)](https://bintray.com/dialog/maven/java-api-schema)
[![PyPI](https://img.shields.io/pypi/v/dialog-api)](https://pypi.org/project/dialog-api/1.2.2) 

Dialog gRPC API Schema.

[API documentation](https://dialogs.github.io/api-schema)

Usage
-----

| Project      | Link                                         |
| ------------ | -------------------------------------------- |
| Java Bot SDK | https://github.com/dialogs/java-bot-sdk      |
| JS Bot SDK   | https://github.com/dialogs/js-bot-sdk        |
| Python       | https://github.com/dialogs/python-bot-sdk    |
| Go API       | https://github.com/dialogs/golang-dialog-api |
| Go (Example) | https://github.com/dialogs/stressbot         |

License
-------

[Apache-2.0](LICENSE)
